#************************************************************************
#*   IRC - Internet Relay Chat, ircd/Makefile
#*   Copyright (C) 1990 Jarkko Oikarinen
#*
#*   This program is free software; you can redistribute it and/or modify
#*   it under the terms of the GNU General Public License as published by
#*   the Free Software Foundation; either version 1, or (at your option)
#*   any later version.
#*
#*   This program is distributed in the hope that it will be useful,
#*   but WITHOUT ANY WARRANTY; without even the implied warranty of
#*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#*   GNU General Public License for more details.
#*
#*   You should have received a copy of the GNU General Public License
#*   along with this program; if not, write to the Free Software
#*   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#*/

# IRCDMODE given in top level Makefile, but added here to make sure
# compilation works if started in ircd subdirectory

CC=cc/debug/noopt/nowarn/include=[-.include]
#CC=cc/nowarn/include=[-.include]

OBJS=channel.obj, ircd.obj, list.obj, s_bsd_vms.obj, s_conf.obj, s_msg.obj, -
     s_numeric.obj, whowas.obj, s_debug.obj, class.obj, hash.obj, note.obj, -
     s_misc.obj! , authuser.obj

SRC=channel.c, ircd.c, list.c, s_bsd_vms.c, s_conf.c, s_msg.c, s_numeric.c, -
     whowas.c, s_debug.c, class.c, note.c, hash.c, s_misc.c! , authuser.c

COMMONOBJS=[-.common]bsd.obj, [-.common]dbuf.obj, -
           [-.common]packet.obj, [-.common]send.obj, -
           [-.common]match.obj, [-.common]parse.obj, [-.common]support.obj

COMMONSRC=[-.common]bsd.c, [-.common]dbuf.c, -
	  [-.common]packet.c, [-.common]send.c, -
	  [-.common]match.c, [-.common]parse.c, [-.common]support.c

all : build

build : ircd

ircd : $(OBJS) $(COMMONOBJS) [-.include]patchlevel.h
	@version
	$(CC) version
	link/exe=ircd $(OBJS), version.obj, $(COMMONOBJS), -
		[-.ircd]ircd/opt
	set prot=(s,o :rwed,g,w) ircd.exe

ircdd : $(OBJS) $(COMMONOBJS) [-.include]patchlevel.h
	@version
	$(CC) version
	link/exe=ircdd/debug $(OBJS), version.obj, $(COMMONOBJS), -
		[-.ircd]ircd/opt
	set prot=(s,o :rwed,g,w) ircdd.exe

[-.common]parse.obj : [-.common]parse.c, [-.include]msg.h [-.include]config.h -
		   [-.include]struct.h [-.include]sys.h [-.include]numeric.h
		set def [-.common]
		mms build
		set def [-.ircd]

[-.common]bsd.obj : [-.common]bsd.c, [-.include]config.h [-.include]common.h -
		 [-.include]struct.h [-.include]sys.h
		set def [-.common]
		mms build
		set def [-.ircd]

[-.common]dbuf.obj : [-.common]dbuf.c, [-.include]config.h, -
		[-.include]common.h, [-.include]struct.h, [-.include]dbuf.h
		set def [-.common]
		mms build
		set def [-.ircd]

[-.common]packet.obj : [-.common]packet.c, [-.include]config.h, -
                    [-.include]common.h, [-.include]struct.h, [-.include]msg.h
		set def [-.common]
		mms build
		set def [-.ircd]

[-.common]send.obj : [-.common]send.c, [-.include]config.h, [-.include]sys.h -
		  [-.include]struct.h [-.include]common.h
		set def [-.common]
		mms build
		set def [-.ircd]

[-.common]match.obj : [-.common]match.c, [-.include]config.h, -
                    [-.include]common.h, [-.include]sys.h
		set def [-.common]
		mms build
		set def [-.ircd]

[-.common]support.obj : [-.common]support.c, [-.include]config.h, -
                      [-.include]sys.h, [-.include]common.h
		set def [-.common]
		mms build
		set def [-.ircd]

# DO NOT DELETE THIS LINE -- make depend depends on it.

channel.obj : [-.include]struct.h, [-.include]config.h, [-.include]dbuf.h
channel.obj : [-.include]numeric.h, channel.h
ircd.obj : [-.include]struct.h, [-.include]config.h
ircd.obj : [-.include]dbuf.h, [-.include]numeric.h
list.obj : [-.include]struct.h, [-.include]config.h, [-.include]dbuf.h
list.obj : [-.include]sys.h
s_bsd_vms.obj : [-.include]struct.h, [-.include]config.h, [-.include]dbuf.h
s_bsd_vms.obj : [-.include]sys.h
s_conf.obj : [-.include]struct.h, [-.include]config.h, [-.include]numeric.h
s_conf.obj : [-.include]dbuf.h, [-.include]sys.h
note.obj : [-.include]struct.h, [-.include]numeric.h
s_misc.obj : [-.include]struct.h, [-.include]config.h, [-.include]dbuf.h
s_msg.obj : [-.include]struct.h, [-.include]config.h
s_msg.obj : [-.include]dbuf.h, [-.include]sys.h, channel.h
s_msg.obj : [-.include]msg.h, [-.include]numeric.h !, [-.include]authuser.h
s_numeric.obj : [-.include]config.h, [-.include]sys.h
s_numeric.obj : [-.include]struct.h
s_numeric.obj : [-.include]dbuf.h, [-.include]numeric.h
whowas.obj : [-.include]struct.h, [-.include]config.h
whowas.obj : [-.include]dbuf.h, [-.include]sys.h
whowas.obj : [-.include]numeric.h
s_debug.obj : [-.include]struct.h
class.obj : [-.include]struct.h, [-.include]class.h
hash.obj : [-.include]struct.h, [-.include]sys.h, [-.include]hash.h
res_init.obj : [-.include]resolv.h, [-.include]nameser.h
res_comp.obj : [-.include]resolv.h, [-.include]nameser.h
res_debug.obj : [-.include]resolv.h, [-.include]nameser.h
res_query.obj : [-.include]resolv.h, [-.include]nameser.h
res_mkquery.obj : [-.include]resolv.h, [-.include]nameser.h
res_send.obj : [-.include]resolv.h, [-.include]nameser.h
!authuser.obj : [-.include]authuser.h
